@@ -3,17 +3,17 @@
 from benedict.serializers import (
     get_format_by_path, get_serializer_by_format, get_serializers_extensions, )
 
+from six import PY2
+
 import errno
 import os
 import requests
 
 
-def autodetect_format(s, default=None):
-    if is_data(s):
-        return default
-    elif is_url(s) or is_filepath(s):
+def autodetect_format(s):
+    if is_url(s) or is_filepath(s):
         return get_format_by_path(s)
-    return default
+    return None
 
 
 def decode(s, format, **kwargs):
@@ -38,8 +38,9 @@ def is_data(s):
 
 
 def is_filepath(s):
-    return any([s.endswith(extension)
-                for extension in get_serializers_extensions()])
+    if any([s.endswith(ext) for ext in get_serializers_extensions()]):
+        return True
+    return os.path.isfile(s)
 
 
 def is_url(s):
@@ -62,10 +63,11 @@ def read_content(s):
     return s
 
 
-def read_file(filepath):
+def read_file(filepath, encoding='utf-8'):
     if os.path.isfile(filepath):
         content = ''
-        with open(filepath, 'r') as file:
+        options = {} if PY2 else { 'encoding':encoding }
+        with open(filepath, 'r', **options) as file:
             content = file.read()
         return content
     return None
@@ -93,9 +95,10 @@ def write_file_dir(filepath):
             raise e
 
 
-def write_file(filepath, content):
+def write_file(filepath, content, encoding='utf-8'):
     # https://stackoverflow.com/questions/12517451/automatically-creating-directories-with-file-output
     write_file_dir(filepath)
-    with open(filepath, 'w+') as file:
+    options = {} if PY2 else { 'encoding':encoding }
+    with open(filepath, 'w+', **options) as file:
         file.write(content)
     return True
