@@ -13,7 +13,6 @@ except ImportError:
     from urllib import urlencode
     from urlparse import parse_qs
 
-import json
 import re
 
 
@@ -31,8 +30,7 @@ class QueryStringSerializer(AbstractSerializer):
             if flat:
                 data = {key: value[0] for key, value in data.items()}
             return data
-        else:
-            raise ValueError('Invalid query string: {}'.format(s))
+        raise ValueError('Invalid query string: {}'.format(s))
 
     def encode(self, d, **kwargs):
         data = urlencode(d, **kwargs)
